## Description

<!-- Provide a brief description of your changes -->

## Type of Change

<!-- Mark the relevant option with an 'x' -->

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Performance improvement
- [ ] Code refactoring

## Related Issues

<!-- Link to related issues, e.g., "Closes #123" or "Fixes #456" -->

## Changes Made

<!-- List the specific changes made in this PR -->

-
-
-

## Testing

<!-- Describe the testing you've performed -->

- [ ] All existing tests pass
- [ ] Added new tests for new functionality
- [ ] Tested on multiple Python versions (if applicable)
- [ ] Benchmarked performance changes (if applicable)

## Checklist

<!-- Ensure all items are completed before submitting -->

- [ ] My code follows the project's style guidelines
- [ ] I have run `black` and `isort` on Python code
- [ ] I have run `cargo fmt` and `cargo clippy` on Rust code
- [ ] I have added tests that prove my fix/feature works
- [ ] I have updated the documentation accordingly
- [ ] I have added docstrings to new functions
- [ ] My changes generate no new warnings
- [ ] I have updated CHANGELOG.md (if applicable)

## Additional Context

<!-- Add any other context about the PR here, such as screenshots, benchmarks, etc. -->
